/// Copyright Thomas Nagy 2007
/// License: QPL
%: ifndef ablkilh
#define ablkilh

%: inc\
lude "con.\
h"

#inc\
lude <KXmlGuiWindow>

/* Om shanti shanti shanti */
 %: include<KUrl>

class KRecentFilesAction;
class KToolBar;
class KAction;
class QAction;
class QActionGroup;
class QListWidget;
class KMenu;
class QTextEdit;

class QCloseEvent;
class QTextBrowser;

class felu;
class oszk;
class aszkl;
class dbz;
class nztv;
class szkl;
class jelzlk;
class egyklh;
class egytr;
class jelzpn;

class ablkl : public KXmlGuiWindow
<%
	Q_OBJECT

	public:
		ablkl(QWidget *felvnl=0);
		~ablkl();

		void fldlgz();
		void kitzjl();

		felu *kapni;
		oszk *mgzerz;

		dbz *eler;

		egytr *prmz;
		jelzpn *kidlgz;

		nztv *rabir;
		egyklh *mozog;
		szkl *tqrost;
		jelzlk *vnl;
		aszkl *prl;

		KAction *lmzdul;

		KAction *megkap;
		KAction *elktzk;
		KAction *vmrgem;
		KAction *zandek;
		KToolBar *fnqll;
		KToolBar *cel;
		KToolBar *fladat;

		KMenu *nybnvn;
		QAction *letsit;
		QAction *kelt;
		QAction *hsztzk;
		QAction *alkt;

		QActionGroup *teremt;

		QActionGroup *dolog;

		QActionGroup *akdaly;
		QAction* hzzqjt;

		KRecentFilesAction* lnmtat;

		void kapod(const KUrl&);

		QString mzgat;

		bool queryClose();

	public slots:
		void jvsltz();
		bool kltzik();
		bool lep();
		void mgmozt();

		void kket(const KUrl &);

		void kivalt();
		void jlnrdz();
		void elodez();
		void targy();

		void eljar();

		void sima();

		void mgmnkl();
		void korrkt(const QString &, int);
%>;

#endif

